@@ -100,9 +100,7 @@ void PluginBabelFish::translateURL()
   }
 
   // Get URL
-  KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
-  if ( !part )
-    return;
+  KHTMLPart *part = static_cast<KHTMLPart *>(parent());
 
   QString query;
   // we check if we have text selected.  if so, we translate that.  if
