@@ -19,6 +19,8 @@
 #include <unistd.h>
 #include <sys/types.h>
 
+#include <qtimer.h>
+
 #include <kdebug.h>
 #include <klocale.h>
 #include <kinstance.h>
@@ -142,7 +144,7 @@ DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
 
   if (parent && parent->inherits ("KonqDirPart"))
   {
-    m_part = dynamic_cast<KonqDirPart*>(parent);
+    m_part = static_cast<KonqDirPart*>(parent);
 
     connect (m_part, SIGNAL (itemRemoved(const KFileItem*)),
              SLOT( slotItemRemoved (const KFileItem*)));
@@ -157,19 +159,20 @@ DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
 DirFilterPlugin::~DirFilterPlugin()
 {
   delete m_pFilterMenu;
+
+  m_part = 0;
+  m_pFilterMenu = 0;
 }
 
 void DirFilterPlugin::slotOpenURL ()
 {
   KURL url = m_part->url();
 
-  kdDebug() << "DirFilterPlugin::slotOpenURL: " << url.url() << endl;
-
   if (m_pURL != url)
   {
     m_pURL = url;
+    m_pMimeInfo.clear();
     m_part->setMimeFilter (SessionManager::self()->restore(url));
-    kdDebug() << "Checking MIME FILTERS for: " << url.url() << endl;
   }
 }
 
@@ -332,12 +335,6 @@ void DirFilterPlugin::slotItemsAdded (const KFileItemList& list)
     return;
   }
 
-  if (m_pURL != url)
-  {
-    m_pURL = url;
-    m_pMimeInfo.clear();
-  }
-
   KFileItemListIterator it (list);
   for (; it.current () ; ++it)
   {
@@ -391,9 +388,8 @@ void DirFilterPlugin::slotItemRemoved (const KFileItem* item)
         filters = m_part->mimeFilter ();
         filters.remove (mimeType);
         m_part->setMimeFilter (filters);
-        KURL url = m_part->url();
-        m_part->openURL (url);
-        SessionManager::self()->save (url, filters);
+        SessionManager::self()->save (m_part->url(), filters);
+        QTimer::singleShot( 0, this, SLOT(slotTimeout()) );
       }
       m_pMimeInfo.remove (mimeType);
     }
@@ -438,5 +434,11 @@ void DirFilterPlugin::slotMultipleFilters()
     SessionManager::self()->useMultipleFilters = true;
 }
 
+void DirFilterPlugin::slotTimeout()
+{
+  if (m_part);
+    m_part->openURL (m_part->url());
+}
+
 
 #include "dirfilterplugin.moc"
