@@ -111,10 +111,13 @@ SettingsPlugin::~SettingsPlugin()
 
 void SettingsPlugin::showPopup()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( !part )
-	return;
+  if( !parent() || !parent()->inherits("KHTMLPart"))
+    return;
 
+
+    KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
+
+    KProtocolManager::reparseConfiguration();
     bool cookies = cookiesEnabled( part->url().url() );
 
     ((KToggleAction*)actionCollection()->action("useproxy"))->setChecked(KProtocolManager::useProxy());
@@ -143,25 +146,27 @@ void SettingsPlugin::showPopup()
 
 void SettingsPlugin::toggleJava()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( part ) {
+  if( parent() && parent()->inherits("KHTMLPart"))
+    {
+       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
         part->setJavaEnabled( ((KToggleAction*)actionCollection()->action("java"))->isChecked() );
     }
 }
 
 void SettingsPlugin::toggleJavascript()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( part ) {
-        part->setJScriptEnabled( ((KToggleAction*)actionCollection()->action("javascript"))->isChecked() );
+  if( parent() && parent()->inherits("KHTMLPart"))
+    {
+       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
+       part->setJScriptEnabled( ((KToggleAction*)actionCollection()->action("javascript"))->isChecked() );
     }
 }
 
 void SettingsPlugin::toggleCookies()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( !part )
-	return;
+  if( !parent() || !parent()->inherits("KHTMLPart"))
+    return;
+    KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
 
     QString advice;
     bool enable = ((KToggleAction*)actionCollection()->action("cookies"))->isChecked();
@@ -193,16 +198,18 @@ void SettingsPlugin::toggleCookies()
 
 void SettingsPlugin::togglePlugins()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( part ) {
+  if( parent() && parent()->inherits("KHTMLPart"))
+    {
+       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
         part->setPluginsEnabled( ((KToggleAction*)actionCollection()->action("plugins"))->isChecked() );
     }
 }
 
 void SettingsPlugin::toggleImageLoading()
 {
-    KHTMLPart *part = dynamic_cast<KHTMLPart *>( parent() );
-    if ( part ) {
+  if( parent() && parent()->inherits("KHTMLPart"))
+    {
+       KHTMLPart *part = static_cast<KHTMLPart *>(parent());
         part->setAutoloadImages( ((KToggleAction*)actionCollection()->action("imageloading"))->isChecked() );
     }
 }
@@ -241,7 +248,7 @@ bool SettingsPlugin::cookiesEnabled( const QString& url )
 
 void SettingsPlugin::toggleProxy()
 {
-    bool enable = !((KToggleAction*)actionCollection()->action("useproxy"))->isChecked();
+    bool enable = ((KToggleAction*)actionCollection()->action("useproxy"))->isChecked();
     int t = enable ? KProtocolManager::ManualProxy : KProtocolManager::NoProxy;
     
     KConfig config("kioslaverc", false, false);
