@@ -53,12 +53,13 @@ KImGalleryPlugin::KImGalleryPlugin( QObject* parent, const char* name, const QSt
 void KImGalleryPlugin::slotExecute()
 {
     m_progressDlg=0L;
-   m_part = dynamic_cast<KonqDirPart *>(parent());
-  if (!m_part) {
-    KMessageBox::sorry( 0L, i18n("KImGalleryPlugin::slotCreateHtml: Program error, please report a bug."));
-    return;
-  }
-  if (!m_part->url().isLocalFile()) {	//TODO support remote URLs too?
+   if ( !parent() || !parent()->inherits("KonqDirPart"))
+   {
+           KMessageBox::sorry( 0L, i18n("KImGalleryPlugin::slotCreateHtml: Program error, please report a bug."));
+           return;
+   }
+   m_part = static_cast<KonqDirPart *>(parent());
+ if (!m_part->url().isLocalFile()) {	//TODO support remote URLs too?
     KMessageBox::sorry(m_part->widget(), i18n("Creating an image gallery works only on local directories."));
     return;
   }
@@ -242,8 +243,9 @@ bool KImGalleryPlugin::createHtml(const KURL& url, const QString& sourceDirName,
 {
   if(m_cancelled) return false;
 
-  KonqDirPart * part = dynamic_cast<KonqDirPart *>(parent());
-
+  if( !parent() || !parent()->inherits("KonqDirPart"))
+        return false;
+  KonqDirPart * part = static_cast<KonqDirPart *>(parent());
   QStringList subDirList;
   if (m_recurseSubDirectories && (recursionLevel >= 0)) { //recursionLevel == 0 means endless
     QDir toplevel_dir = QDir( sourceDirName );
