@@ -22,20 +22,21 @@
 
 #include <qregexp.h>
 
-#include <kapp.h>
-#include <kaction.h>
+#include <krun.h>
 #include <kdebug.h>
+#include <kaction.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <ktrader.h>
+#include <kconfig.h>
 #include <kio/job.h>
+#include <kservice.h>
 #include <kinstance.h>
 #include <kpopupmenu.h>
 #include <dcopclient.h>
 #include <khtml_part.h>
-#include <ksimpleconfig.h>
-#include <kprotocolmanager.h>
 #include <kgenericfactory.h>
+#include <kprotocolmanager.h>
 
 #include "uachangerplugin.h"
 
@@ -148,7 +149,9 @@ void UAChangerPlugin::slotStarted( KIO::Job* )
 {
   m_currentURL = m_part->url();
 
-  if (m_currentURL.isEmpty ())
+  if (m_currentURL.isEmpty () ||
+      (m_currentURL.protocol().find("http", 0, false) != 0 &&
+       m_currentURL.protocol().find("webdav", 0, false) != 0))
   {
     m_pUAMenu->setEnabled ( false );
   }
@@ -161,12 +164,11 @@ void UAChangerPlugin::slotStarted( KIO::Job* )
 
 void UAChangerPlugin::slotAboutToShow()
 {
-  int count;
   KProtocolManager proto;
 
   if (!m_config)
   {
-    m_config = new KSimpleConfig( "kio_httprc" );
+    m_config = new KConfig( "kio_httprc" );
     parseDescFiles();
   }
 
@@ -174,7 +176,7 @@ void UAChangerPlugin::slotAboutToShow()
     loadSettings();
 
   m_pUAMenu->popupMenu()->clear();
-  m_pUAMenu->popupMenu()->insertTitle(i18n("Identify As:"), count++);
+  m_pUAMenu->popupMenu()->insertTitle(i18n("Identify As:"));
 
   m_currentUserAgent = proto.userAgentForHost(m_currentURL.host());
 
@@ -193,14 +195,7 @@ void UAChangerPlugin::slotAboutToShow()
     m_pUAMenu->popupMenu()->insertSeparator();
   }
 
-  count = m_pUAMenu->popupMenu()->count();
-
-/*
-  m_pUAMenu->popupMenu()->insertItem( i18n("Apply to Entire Site"), this,
-                                      SLOT(slotApplyToDomain()),
-                                      0, ++count );
-  m_pUAMenu->popupMenu()->setItemChecked(count, m_bApplyToDomain);
-*/
+  int count = m_pUAMenu->popupMenu()->count();
 
   m_pUAMenu->popupMenu()->insertItem( i18n("Reload Identifications"), this,
                                       SLOT(slotReloadDescriptions()),
@@ -209,11 +204,6 @@ void UAChangerPlugin::slotAboutToShow()
                                       SLOT(slotDefault()), 0, ++count );
   m_pUAMenu->popupMenu()->setItemEnabled(count, (proto.defaultUserAgent()!=
                                                  m_currentUserAgent));
-/*
-  m_pUAMenu->popupMenu()->insertSeparator();
-  m_pUAMenu->popupMenu()->insertItem( i18n("Configure..."), this,
-                                      SLOT(slotConfigure()));
-*/
 }
 
 void UAChangerPlugin::slotItemSelected( int id )
@@ -288,24 +278,18 @@ void UAChangerPlugin::slotDefault()
 void UAChangerPlugin::updateIOSlaves ()
 {
   // Inform running http(s) io-slaves about the change...
-  if ( !kapp->dcopClient()->isAttached() )
-    kapp->dcopClient()->attach();
+  DCOPClient * client = new DCOPClient ();
 
-  {
+  if (!client->attach())
+    kdDebug() << "Can't connect with DCOP server." << endl;
+  
       QByteArray data;
       QDataStream stream( data, IO_WriteOnly );
-      stream << QString("http");
-      kapp->dcopClient()->send( "*", "KIO::Scheduler",
-                                "reparseSlaveConfiguration(QString)", data );
+  stream << QString::null;
+  client->send( "*", "KIO::Scheduler", "reparseSlaveConfiguration(QString)",
+                data );
+  delete client;
   }
-  {
-      QByteArray data;
-      QDataStream stream( data, IO_WriteOnly );
-      stream << QString("https");
-      kapp->dcopClient()->send( "*", "KIO::Scheduler",
-                                "reparseSlaveConfiguration(QString)", data );
-  }
-}
 
 QString UAChangerPlugin::filterHost(const QString &hostname)
 {
@@ -326,45 +310,95 @@ QString UAChangerPlugin::filterHost(const QString &hostname)
   if (isIPAddress)
     return hostname;
 
-  // If apply to entire site is not set then only apply
-  // the policy to the current site.
-  if (m_bApplyToDomain && !hostname.isEmpty())
+  // Return the TLD...
+  return findTLD(hostname);
+}
+
+
+// TODO: Probably need to move this code...
+QString UAChangerPlugin::findTLD (const QString &hostname)
+{
+  QString tld = hostname;
+  
+  if ( !tld.isEmpty () )
   {
-    QStringList partList = QStringList::split('.', hostname, false);
+    QStringList partList = QStringList::split('.', tld, false);
     int count = partList.count();
 
-    if (count != 2 || !(count == 3 && partList[1].length() <= 2 &&
-                        partList[2].length() == 2))
+    if (count > 2)
     {
-      partList.remove (partList.begin());
-      return partList.join(".");
+      QStringList tlds;
+      
+      // Classical TLD's
+      tlds << "com" << "net" << "org" << "gov" << "edu" << "mil" << "int";
+      
+      // The new seven TLD's
+      tlds << "aero" << "biz" << "coop" << "info" << "museum" << "name" << "pro";
+      
+      QStringList::Iterator topTLD = partList.fromLast ();
+      
+      if ( (*topTLD).length() < 3 )
+      {
+        --topTLD;
+        
+        if ( (*topTLD).length () < 3 )
+        {
+          --topTLD;
+          
+          // Remove anymore known TLD's...
+          while ( topTLD != partList.begin() && tlds.findIndex (*topTLD) != -1 )
+            --topTLD;          
+                   
+          // Remove everything upto this point...
+          partList.erase (partList.begin(), topTLD);
+          
+          // If we still have something, then create a TLD out of it.
+          if (partList.count ()) 
+            tld = partList.join (".");
+    }
+        else
+        {
+          while ( topTLD != partList.begin() && tlds.findIndex (*topTLD) != -1 )
+            --topTLD;
+          
+          partList.erase (partList.begin(), topTLD);
+          
+          if (partList.count ())
+            tld = partList.join (".");          
+        }
+      }
+      else
+      {
+        --topTLD;
+        
+        while ( topTLD != partList.begin () && tlds.findIndex (*topTLD) != -1 )
+          --topTLD;
+          
+        partList.erase (partList.begin (), topTLD);
+        
+        if (partList.count())
+          tld = partList.join (".");
+      }
     }
   }
 
-  return hostname;
+  return tld;
 }
 
 void UAChangerPlugin::saveSettings()
 {
-  if(!m_bSettingsLoaded) return;
+  if(!m_bSettingsLoaded)
+    return;
 
   KConfig cfg ("uachangerrc", false, false);
   cfg.setGroup ("General");
-
-  cfg.writeEntry ("applyToDomain", m_bApplyToDomain);
 }
 
 void UAChangerPlugin::loadSettings()
 {
   KConfig cfg ("uachangerrc", false, false);
   cfg.setGroup ("General");
-
-  m_bApplyToDomain = cfg.readBoolEntry ("applyToDomain", true);
   m_bSettingsLoaded = true;
 }
 
-void UAChangerPlugin::slotApplyToDomain()
-{
-  m_bApplyToDomain = !m_bApplyToDomain;
-}
 #include "uachangerplugin.moc"
