@@ -31,7 +31,7 @@
 
 class KHTMLPart;
 class KActionMenu;
-class KSimpleConfig;
+class KConfig;
 
 namespace KIO
 {
@@ -53,12 +53,12 @@ protected slots:
   void updateIOSlaves();
 
   void slotAboutToShow();
-  void slotApplyToDomain();
   void slotItemSelected(int);
   void slotStarted(KIO::Job*);
   void slotReloadDescriptions();
 
 protected:
+  QString findTLD (const QString &hostname);
   QString filterHost(const QString &hostname);
 
 private:
@@ -66,12 +66,11 @@ private:
   void saveSettings();
 
   int m_selectedItem;
-  bool m_bApplyToDomain;
   bool m_bSettingsLoaded;
 
   KHTMLPart* m_part;
   KActionMenu* m_pUAMenu;
-  KSimpleConfig* m_config;
+  KConfig* m_config;
 
   KURL m_currentURL;
   QString m_currentUserAgent;
