@@ -17,7 +17,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_webarchiver.cpp,v 1.17 2001/12/04 11:32:40 lukas Exp $ */
+/* $Id: plugin_webarchiver.cpp,v 1.17.2.2 2002/06/14 07:49:44 mlaurent Exp $ */
 
 /* 
  * There are two recursions within this code:
@@ -69,9 +69,15 @@ PluginWebArchiver::~PluginWebArchiver()
 void PluginWebArchiver::slotSaveToArchive()
 {  
   // ## Unicode ok?
-  KHTMLPart * part = dynamic_cast<KHTMLPart *>(parent());
+  if( !parent() || !parent()->inherits("KHTMLPart"))
+    return;
+  KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
+  
   QString archiveName = QString::fromUtf8(part->htmlDocument().title().string().utf8());
-  //archiveName = KURL::encode_string(archiveName); //lukas: this looks _ugly_!
+
+  // Replace space with underscore, proposed Frank Pieczynski <pieczy@knuut.de>
+  archiveName = archiveName.simplifyWhiteSpace().replace( QRegExp("\\s+"), "_");
+ 
   archiveName = QDir::homeDirPath() + "/" + archiveName + ".war"; //Thanks ade
 
   KURL url = KFileDialog::getSaveFileName(archiveName, "*.tgz *.war|Web Archives", part->widget(), 
@@ -133,7 +139,7 @@ void PluginWebArchiver::saveFile( const QString& fileName,  const KHTMLPart *par
   KTempFile tmpFile;   
   if (!(tmpFile.status())) {
     QTextStream* textStream = tmpFile.textStream();
-    textStream->setEncoding(QTextStream::Unicode);
+    textStream->setEncoding(QTextStream::Locale);
     this->saveToArchive(part, textStream);  
 
     tmpFile.close(); 
